@@ -21,9 +21,13 @@ from copy import deepcopy
 from typing import Any, Dict, Optional, Sequence, Union
 
 import pytorch_lightning as pl
+import torch
+from lightning_lite.utilities import rank_zero_info
+from lightning_lite.utilities.distributed import ReduceOp
+from lightning_lite.utilities.enums import _StrategyType
 from pytorch_lightning.callbacks import BaseFinetuning
+from pytorch_lightning.strategies.strategy import Strategy
 from pytorch_lightning.trainer.states import TrainerFn
-from pytorch_lightning.utilities import _StrategyType, rank_zero_info
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from pytorch_lightning.utilities.rank_zero import rank_zero_debug, rank_zero_warn
 from torch.optim.optimizer import Optimizer
@@ -75,6 +79,12 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         Currently, :class:`~finetuning_scheduler.fts.FinetuningScheduler` does not support the use of multiple
         :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint` or
         :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping` callback instances.
+
+    .. note::
+
+       While :class:`~finetuning_scheduler.fts.FinetuningScheduler` supports the use of
+       :external+torch:class:`~torch.distributed.optim.ZeroRedundancyOptimizer`, setting ``overlap_with_ddp`` to
+       ``True`` is not supported because that optimizer mode only supports a single parameter group.
     """
 
     def __init__(
@@ -210,6 +220,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         return (
             _StrategyType.DP,
             _StrategyType.DDP,
+            _StrategyType.DDP_FORK,
             _StrategyType.DDP_SPAWN,
             # _StrategyType.DEEPSPEED,  # support to be re-evaluated if add optimizer pg functionality added to DS API
             _StrategyType.DDP_SHARDED,
@@ -225,7 +236,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The target
                 :external+pl:class:`~pytorch_lightning.core.module.LightningModule` to freeze parameters of
         """
-        self.freeze(modules=pl_module)
+        self.freeze(modules=pl_module, train_bn=False)
 
     def step(self) -> None:
         """Prepare and execute the next scheduled fine-tuning level
@@ -322,6 +333,17 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             optimizer.param_groups = BaseFinetuning._apply_mapping_to_param_groups(
                 self._fts_state._fts_ckpt_metadata["best_ckpt_pgs"][opt_idx], dict(self.pl_module.named_parameters())
             )
+            if hasattr(optimizer, "consolidate_state_dict"):
+                # for optimizers that shard their states like (e.g. ZeroRedundancyOptimizer, OSS), we need to clear
+                # local optimizer partition caches and repartition to support restoring across multiple depths
+                partition_params = (
+                    optimizer._partition_parameters
+                    if callable(optimizer._partition_parameters)
+                    else optimizer.partition_parameters
+                )
+                optimizer._clear_cache()
+                optimizer.optim.param_groups = partition_params()[optimizer.rank]
+                optimizer._sync_param_groups(optimizer.optim.param_groups, optimizer.param_groups)
         # we're restoring everything but callbacks and loops, otherwise, checkpoint_connector.restore() could be used
         assert self.pl_module.trainer.checkpoint_callback is not None
         checkpoint_path = self.pl_module.trainer.checkpoint_callback.best_model_path  # type: ignore[attr-defined]
@@ -360,7 +382,48 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                         "we're reinitializing the lr scheduler."
                     )
 
-    def setup(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", stage: Optional[str] = None) -> None:
+    def _reduce_transition(self, strategy: Strategy, decision: bool) -> bool:
+        """Reduce a transition decision across all world processes (effectively a global `any` collective)
+
+        Args:
+            strategy (Strategy): The PL :external+pl:class:`~pytorch_lightning.strategies.Strategy` context to use.
+            decision (bool): The local process decision.
+
+        Returns:
+            bool: The reduced decision across all world processes.
+        """
+        decision = torch.tensor(int(decision), device=strategy.root_device)
+        decision = bool(strategy.reduce(decision, reduce_op=ReduceOp.SUM))
+        return decision
+
+    def _sync_es_state(self, trainer: "pl.Trainer") -> None:
+        """Synchronize the :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping` callback transition state
+        across distributed processes to avoid rare transition divergences when the user does not set ``sync_dist``
+        to ``True`` in logging the monitored metric.
+
+        Args:
+            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
+                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+        """
+        early_stopping_callback = trainer.early_stopping_callback
+        assert early_stopping_callback is not None
+        # reset the FTSEarlyStopping state in every distributed process if any world process is ready to transition to
+        # the next fine-tuning phase
+        should_reset_es = early_stopping_callback.es_phase_complete
+        should_reset_es = self._reduce_transition(trainer.strategy, should_reset_es)
+        if should_reset_es != early_stopping_callback.es_phase_complete:
+            warn_msg = (
+                "The FTSEarlyStopping quantity you are monitoring is not being synchronized across processes and FTS"
+                " has detected that two or more world processes are disagreeing on whether to continue the current"
+                " training phase. Training is continuing by transitioning all training processes to the next"
+                " fine-tuning phase when the early stopping conditions of any training process are met. To avoid this"
+                " behavior in the future, you may want to either log the monitored metric with ``sync_dist`` set to"
+                " ``True`` or increase the configured FTSEarlyStopping ``min_delta``."
+            )
+            rank_zero_warn(warn_msg)
+            early_stopping_callback._transition_es_phase()
+
+    def setup(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", stage: str) -> None:
         """Validate a compatible :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy is being used and
         ensure all :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback dependencies are met. If a valid
         configuration is present, then either dump the default fine-tuning schedule OR
@@ -440,8 +503,15 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             MisconfigurationException: If more than 1 optimizers are configured indicates a configuration error
         """
         if len(trainer.optimizers) > 1:
-            raise MisconfigurationException("fts currently only supports a single-optimizer configuration")
-        self._is_supported_lr(type(trainer.lr_scheduler_configs[0].scheduler))
+            raise MisconfigurationException("FTS currently only supports a single-optimizer configuration")
+        if getattr(trainer.optimizers[0], "_overlap_with_ddp", False):
+            raise MisconfigurationException(
+                "Configuring an optimizer using `overlap_with_ddp=True` is not supported"
+                " with FTS since that optimizer mode only supports a single parameter"
+                " group."
+            )
+        if trainer.lr_scheduler_configs:
+            self._is_supported_lr(type(trainer.lr_scheduler_configs[0].scheduler))
         if self.curr_depth == 0:
             assert isinstance(self.ft_schedule, Dict)
             self._validate_opt_init(trainer.optimizers[0], self.ft_schedule)
@@ -510,6 +580,11 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         )
         if not self.epoch_transitions_only:  # if we're considering FTSEarlyStopping criteria
             assert early_stopping_callback is not None
+            # in the edge case where transition decisions diverge among distributed processes because the user is
+            # running in a distributed context without ``sync_dist`` set to ``True`` and ``min_delta`` is
+            # sufficiently low, we should reduce the transition decision over all training processes to avoid deadlocks
+            if early_stopping_callback.reduce_transition_decisions:
+                self._sync_es_state(trainer)
             is_final_phase = early_stopping_callback.final_phase  # type: ignore[attr-defined]
             epoch_driven_transition = (
                 True if not is_final_phase and (0 <= curr_max_epoch <= trainer.current_epoch) else False
@@ -550,8 +625,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             )
             if not self.epoch_transitions_only:
                 assert isinstance(trainer.early_stopping_callback, FTSEarlyStopping)
-                trainer.early_stopping_callback.es_phase_complete = False
-                trainer.early_stopping_callback.wait_count = 0
+                trainer.early_stopping_callback._reset_es_phase()
         if self.depth_remaining == 0:
             if not self.epoch_transitions_only:
                 assert isinstance(trainer.early_stopping_callback, FTSEarlyStopping)
@@ -584,8 +658,9 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         to ensure final training state is consistent with epoch semantics.
 
         Args:
-            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): _description_
-            pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): _description_
+            trainer: The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+            pl_module  (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
+                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
         """
         assert self._fts_state._ft_sync_objects is not None
         self.sync(self._fts_state._ft_sync_objects, self._fts_state._ft_sync_props)
